
User's Guide
============

``bewegung`` - a versatile video renderer

.. warning::

    ``bewegung``'s development status is "**well-tested alpha**". Its API should not be considered stable until the project is labeled "beta" or better, although significant changes are very unlikely.

.. toctree::
   :maxdepth: 2
   :caption: Table of Contents

   about
   installation
   getting_started
   gallery
   canvas
   anatomy
   algebra
   debug

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
